@@ -231,10 +231,21 @@ class GoogleOrgClient(BasePlatformClient):
                         transport_name,
                         credentials_path
                     ):
-                        # Transport is cached as configured, skip setup
-                        successful_transports.append(transport_name)
-                        if self.verbose:
-                            print(f"✓ {transport_name} already configured (cached)")
+                        # Transport is cached as configured, but still need to initialize
+                        try:
+                            # In Colab mode, we may not have explicit credentials
+                            if self.current_environment == Environment.COLAB and not self.credentials:
+                                setup_data = None  # Transports will handle Colab auth internally
+                            else:
+                                setup_data = {'credentials': self.credentials}
+                            if transport.setup(setup_data):
+                                successful_transports.append(transport_name)
+                                if self.verbose:
+                                    print(f"✓ {transport_name} already configured (cached)")
+                            else:
+                                failed_transports.append(transport_name)
+                        except Exception:
+                            failed_transports.append(transport_name)
                     elif hasattr(transport, 'is_setup') and transport.is_setup():
                         # Transport reports it's setup (but not in cache)
                         successful_transports.append(transport_name)
