@@ -236,10 +236,17 @@ class GooglePersonalClient(BasePlatformClient):
                         transport_name,
                         credentials_path
                     ):
-                        # Transport is cached as configured, skip setup
-                        successful_transports.append(transport_name)
-                        if self.verbose:
-                            print(f"✓ {transport_name} already configured (cached)")
+                        # Transport is cached as configured, but still need to initialize
+                        try:
+                            setup_data = {'credentials': self.credentials}
+                            if transport.setup(setup_data):
+                                successful_transports.append(transport_name)
+                                if self.verbose:
+                                    print(f"✓ {transport_name} already configured (cached)")
+                            else:
+                                failed_transports.append(transport_name)
+                        except Exception:
+                            failed_transports.append(transport_name)
                     elif hasattr(transport, 'is_setup') and transport.is_setup():
                         # Transport reports it's setup (but not in cache)
                         successful_transports.append(transport_name)
@@ -670,7 +677,7 @@ class GooglePersonalClient(BasePlatformClient):
             print("\n🔧 OAuth2 credentials not found. Starting setup wizard...")
         
         # Run the wizard
-        creds_file = check_or_create_credentials(self.email, self.verbose)
+        creds_file = check_or_create_credentials(self.email, self.verbose, self.force_oauth)
         
         if not creds_file:
             if self.verbose:
@@ -682,7 +689,7 @@ class GooglePersonalClient(BasePlatformClient):
     def wizard(self) -> None:
         """Public entry point for manual wizard launch"""
         from .wizard import create_oauth2_wizard
-        create_oauth2_wizard(self.email, verbose=True)
+        create_oauth2_wizard(self.email, verbose=True, force_oauth=self.force_oauth)
     
     # ===== OAuth2 Flow Methods =====
     
